MTP: changes to use new usb_request support in libusbhost

Change-Id: Ic091eab166a66efcde0395dcebbbc513f2322fca
Signed-off-by: Mike Lockwood <lockwood@android.com>
diff --git a/media/mtp/MtpEventPacket.h b/media/mtp/MtpEventPacket.h
index 30ae869..660baad 100644
--- a/media/mtp/MtpEventPacket.h
+++ b/media/mtp/MtpEventPacket.h
@@ -34,8 +34,8 @@
 #endif
 
 #ifdef MTP_HOST
-    // read our buffer from the given endpoint
-    int                 read(struct usb_endpoint *ep);
+    // read our buffer with the given request
+    int                 read(struct usb_request *request);
 #endif
 
     inline MtpEventCode     getEventCode() const { return getContainerCode(); }